Package: FSinR
Maintainer: Alfonso Jiménez-Vílchez <i52jivia@uco.es>
Language: en-US
Type: Package
Title: Feature Selection in R
Description: Feature subset selection algorithms modularized in search algorithms and measure utilities.
Version: 2.0.10
Date: 2025-11-12
Authors@R: c(
    person("Alfonso",     "Jiménez-Vílchez", email = "i52jivia@uco.es", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-9800-8160")),
    person("Francisco",   "Aragón-Royón", email = "far@decsai.ugr.es", role = "aut", comment = c(ORCID = "0000-0003-2025-5898")),
    person("Adan M.",     "Rodriguez", email = "i32muroa@gmail.com", role = "aut"),
    person("Antonio",     "Arauzo-Azofra", email = "arauzo@uco.es", role = "aut", comment = c(ORCID = "0000-0002-2486-5792")),
    person("José Manuel", "Benítez", email = "J.M.Benitez@decsai.ugr.es", role = "aut", comment = c(ORCID = "0000-0002-2346-0793")))
Repository: CRAN
License: GPL-3
Imports: digest, caret, Rdpack, GA, dplyr, tidyr, prodlim, rlang,
        purrr, e1071
RdMacros: Rdpack
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: testthat, knitr, rmarkdown, RSNNS, randomForest
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-11-12 00:23:50 UTC; alfonso
Author: Alfonso Jiménez-Vílchez [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-9800-8160>),
  Francisco Aragón-Royón [aut] (ORCID:
    <https://orcid.org/0000-0003-2025-5898>),
  Adan M. Rodriguez [aut],
  Antonio Arauzo-Azofra [aut] (ORCID:
    <https://orcid.org/0000-0002-2486-5792>),
  José Manuel Benítez [aut] (ORCID:
    <https://orcid.org/0000-0002-2346-0793>)
Date/Publication: 2025-11-12 00:40:02 UTC
Built: R 4.6.0; ; 2026-04-30 11:30:56 UTC; unix
