# Generated by roxygen2: do not edit by hand

export(IEConsistency)
export(IEPConsistency)
export(Jd)
export(LCC)
export(LasVegas)
export(MDLC)
export(ReliefFeatureSetMeasure)
export(antColony)
export(binaryConsistency)
export(breadthFirst)
export(chiSquared)
export(cramer)
export(deepFirst)
export(determinationCoefficient)
export(directFeatureSelection)
export(directSearchAlgorithm)
export(featureSelection)
export(filterEvaluator)
export(fscore)
export(gainRatio)
export(geneticAlgorithm)
export(giniIndex)
export(hillClimbing)
export(hybridFeatureSelection)
export(hybridSearchAlgorithm)
export(is.discrete)
export(isDataframeContinuous)
export(isDataframeDiscrete)
export(mutualInformation)
export(normalizedRelief)
export(normalizedReliefFeatureSetMeasure)
export(relief)
export(roughsetConsistency)
export(searchAlgorithm)
export(selectDifference)
export(selectKBest)
export(selectPercentile)
export(selectSlope)
export(selectThreshold)
export(selectThresholdRange)
export(sequentialBackwardSelection)
export(sequentialFloatingBackwardSelection)
export(sequentialFloatingForwardSelection)
export(sequentialForwardSelection)
export(simulatedAnnealing)
export(symmetricalUncertain)
export(tabu)
export(whaleOptimization)
export(wrapperEvaluator)
import(GA)
import(caret)
import(digest)
import(dplyr)
import(e1071)
import(prodlim)
import(rlang)
import(tidyr)
importFrom(Rdpack,reprompt)
importFrom(digest,digest)
importFrom(purrr,map_dbl)
importFrom(rlang,.data)
importFrom(rlang,UQ)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,complete.cases)
importFrom(stats,cor.test)
importFrom(stats,cov)
importFrom(stats,lm)
importFrom(stats,model.frame)
importFrom(stats,runif)
importFrom(utils,capture.output)
